@@ -366,13 +366,15 @@ RetrieveISFromInterleaveInformationTable(
   );
 
 /**
-  Clear previous pools goal configs and - if pools goal configs is specified - replace them with new one.
+  Clear previous regions goal configs and - if regions goal configs is specified - replace them with new one.
 
-  1. Clear previous pools goal configs on all affected dimms
-  2. [OPTIONAL] Send new pools goal configs to dimms
+  1. Clear previous regions goal configs on all affected dimms
+  2. [OPTIONAL] Send new regions goal configs to dimms
   3. Set information about synchronization with dimms
 
   @param[in] pDimmList Head of the list of all NVM DIMMs in the system
+  @param[in] DimmsNum Number of dimms in pDimmList
+  @param[in] ReservedSizeIsZero Indicate whether the reserved size is zero
   @param[out] pCommandStatus Pointer to command status structure
 
   @retval EFI_SUCCESS success
@@ -383,6 +385,7 @@ EFI_STATUS
 ApplyGoalConfigsToDimms(
   IN     DIMM **ppDimms,
   IN     UINT32 DimmsNum,
+  IN     BOOLEAN ReservedSizeIsZero,
      OUT COMMAND_STATUS *pCommandStatus
   );
 
@@ -493,8 +496,7 @@ ADNamespaceMinAndMaxAvailableSizeOnIS(
 EFI_STATUS
 RetrieveGoalConfigsFromPlatformConfigData(
   IN OUT LIST_ENTRY *pDimmList,
-  IN     BOOLEAN RestoreCorrupt,
-  IN     BOOLEAN CheckSupportedConfigDimms
+  IN     BOOLEAN RestoreCorrupt
   );
 
 /**
